<?php
/**
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2015 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class trustami extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'trustami';
        $this->tab = 'front_office_features';
        $this->version = '1.0.8';
        $this->author = 'Trustami GmbH';
        $this->need_instance = 0;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Badge for Shop Reviews + Google Stars | Trustami');
        global $cookie;
        $iso_code = Language::getIsoById( (int)$cookie->id_lang );

          if ($iso_code == "de") {
            $this->description = $this->l('Trustami Plugin für PrestaShop. Mit dem Vertrauenssiegel von Trustami sammeln Sie alle Ihre existierenden Bewertungen an einem Ort aus allen Quellen. Trustami bietet einen einzigartigen Service, bei dem die verstreuten Bewertungen eines Händlers automatisch verknüpft, aktualisiert und verifiziert werden. Mit diesem Plugin installieren und konfigurieren Sie das Trustami Vertrauenssiegel mit wenigen Klicks.');
          }
          else{
            $this->description = $this->l('Trustami plugin for PrestaShop. Trustami - One badge for all your customer reviews. Trustami collects, analyzes and presents a users’ distributed social media data in a standardized and user-friendly format to fill the need for trust in online interactions.Trustami enables users to collect ratings and reviews from all networks and show a trust badge.');
                  }
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        Configuration::updateValue('TRUSTAMI_LIVE_MODE', false);

        include(dirname(__FILE__).'/sql/install.php');

        return parent::install() &&
            $this->registerHook('displayTop') &&
            $this->registerHook('displayFooter') &&
            $this->registerHook('displayLeftColumn') &&
            $this->registerHook('displayRightColumn') &&
            $this->registerHook('displayRightColumnProduct');
    }

    public function uninstall()
    {
        Configuration::deleteByName('TRUSTAMI_LIVE_MODE');

        include(dirname(__FILE__).'/sql/uninstall.php');

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent(){
    /**
     * If values have been submitted in the form, process.
     */
    if (((bool)Tools::isSubmit('submitTrustamiModule')) == true) {
        $this->postProcess();
    }

    $this->context->smarty->assign('module_dir', $this->_path);
    global $cookie;
    $iso_code = Language::getIsoById( (int)$cookie->id_lang );

      if ($iso_code == "de") {
        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure_de.tpl');
      } else {
        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
      }
        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitTrustamiModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm(){
    $default_language = Configuration::get('PS_LANG_DEFAULT');
    global $cookie;
    $id_lang = $cookie->id_lang;

    $options1 = array(
       array('id_category_parent' => 1,'name' => $this->l('Disabled') ),
       array('id_category_parent' => 2,'name' => $this->l('Trust Badge Standard (recommended)') ),
       array('id_category_parent' => 3,'name' => $this->l('Trust Badge Mini') ),
       array('id_category_parent' => 4,'name' => $this->l('Trust Badge Box') ),
       array('id_category_parent' => 5,'name' => $this->l('Trust Badge Comments') ),
    );

    $options2 = array(
       array('id_category_parent' => 1,'name' => $this->l('Disabled') ),
       array('id_category_parent' => 2,'name' => $this->l('Trust Badge Standard') ),
       array('id_category_parent' => 3,'name' => $this->l('Trust Badge Mini') ),
       array('id_category_parent' => 4,'name' => $this->l('Trust Badge Box (recommended)') ),
    );

    $options3 = array(
       array('id_category_parent' => 1,'name' => $this->l('Disabled') ),
       array('id_category_parent' => 2,'name' => $this->l('Trust Badge Standard') ),
       array('id_category_parent' => 3,'name' => $this->l('Trust Badge Mini (recommended)') ),
       array('id_category_parent' => 4,'name' => $this->l('Trust Badge Box') ),
    );

    $options4 = array(
        array('id_category_parent' => 1,'name' => $this->l('Disabled') ),
        array('id_category_parent' => 2,'name' => $this->l('Trust Badge Standard') ),
        array('id_category_parent' => 3,'name' => $this->l('Trust Badge Box') ),
        array('id_category_parent' => 4,'name' => $this->l('Trust Badge Mini') ),
        array('id_category_parent' => 5,'name' => $this->l('Trust Badge Sticker') ),
        array('id_category_parent' => 6,'name' => $this->l('Trust Badge Text') ),
        array('id_category_parent' => 7,'name' => $this->l('Trust Badge Button') ),
        array('id_category_parent' => 8,'name' => $this->l('Trust Badge Social') ),
        array('id_category_parent' => 9,'name' => $this->l('Trust Badge Duo') ),
        array('id_category_parent' => 10,'name' => $this->l('Trust Badge Stars') ),
        array('id_category_parent' => 11,'name' => $this->l('Trust Badge Comments') ),
        array('id_category_parent' => 12,'name' => $this->l('Shopauskunft Trust Badge') ),
    );

    $optionsyn = array(
      array('id_category_parent' => 1,'name' => $this->l('Yes') ),
      array('id_category_parent' => 2,'name' => $this->l('No') ),
    );

    $optionsbox = array(
      array( 'id' => 'on', 'value' => 1, 'label' => $this->l('Yes')),
      array( 'id' => 'off', 'value' => 0, 'label' => $this->l('No')),
    );

    $optionsadv = array(
      array('id_category_parent' => 1,'name' => $this->l('Disabled') ),
      array('id_category_parent' => 2,'name' => $this->l('ID') ),
      array('id_category_parent' => 3,'name' => $this->l('Class') ),
    );

        return array(
          'form' => array(
              'legend' => array(
              'title' => $this->l('Settings'),
              'icon' => 'icon-cogs'
              ),
              'input' => array(
                  array(
                    'type' => 'text',
                    'class' => 'fixed-width-xl',
                    'name' => 'cardId',
                    'label' => $this->l('Trustami ID'),
                    'required' => true,
                    'hint' => $this->l('Your Trustami ID can be found in your user account at app.trustami.com under the Settings menu option.')
                  ),
                  array(
                    'name' => 'cid_line_end',
                    'type' => 'free'
                  ),
                  array(
                    'name' => 'cfg_line',
                    'type' => 'free',
                    'label' => $this->l('Trust Badge Position:'),
                    'hint' => $this->l('Some Hooks might not be available depending on the Shop Version. Hint: If the selected trust badge is not displayed, it can be activated by logging in to app.trustami.com')
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display in the header'),
                    'name' => 'headerIn',
                    'options' => array(
                      'query' => $options3,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display in the left category section'),
                    'name' => 'leftColumn',
                    'options' => array(
                      'query' => $options2,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display in the right section'),
                    'name' => 'rightColumn',
                    'options' => array(
                      'query' => $options2,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display in the product description'),
                    'name' => 'product',
                    'options' => array(
                      'query' => $options3,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display in the footer'),
                    'name' => 'footerIn',
                    'options' => array(
                      'query' => $options1,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge text in the footer'),
                    'name' => 'textOnly',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display overlay trust badge'),
                    'name' => 'overlay',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display frame trust badge'),
                    'name' => 'overlayFrame',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display list trust badge'),
                    'name' => 'overlayList',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge sticker'),
                    'name' => 'overlaySticker',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge button'),
                    'name' => 'overlayButton',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge social'),
                    'name' => 'overlaySocial',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge duo'),
                    'name' => 'overlayDuo',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display trust badge stars'),
                    'name' => 'overlayStars',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'type' => 'switch',
                    'label' => $this->l('Display Shopauskunft trust badge'),
                    'name' => 'overlayShopak',
                    'required' => false,
                    'is_bool' => true,
                    'values' =>  $optionsbox
                  ),
                  array(
                    'name' => 'cfg_end_line',
                    'type' => 'free',
                    'label' => $this->l('')
                  ),
                  array(
                    'name' => 'adv_line',
                    'type' => 'free',
                    'label' => $this->l('Custom Element Settings:')
                  ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Display trust badge in a different element (1/3)'),
                    'name' => 'advElement',
                    'options' => array(
                      'query' => $optionsadv,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                  array(
                    'type' => 'text',
                    'class' => 'fixed-width-xl',
                    'name' => 'advName',
                    'label' => $this->l('Class/ID name (2/3)')
                    ),
                  array(
                    'type' => 'select',
                    'label' => $this->l('Trust badge type (3/3)'),
                    'name' => 'advBadge',
                    'options' => array(
                      'query' => $options4,
                      'id' => 'id_category_parent',
                      'name' => 'name'
                    ),
                  ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }
    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
      return array(
          'cardId' => Configuration::get('cardId', ''),
          'cid_line_end' => Configuration::get('cid_line_end', ''),
          'cfg_line' => Configuration::get('cfg_line', ''),
          'cfg_end_line' => Configuration::get('cfg_end_line', ''),
          'adv_line' => Configuration::get('adv_line', ''),
          'headerIn' => Configuration::get('headerIn', null),
          'rightColumn' => Configuration::get('rightColumn', null),
          'leftColumn' => Configuration::get('leftColumn', null),
          'footerIn' => Configuration::get('footerIn', null),
          'product' => Configuration::get('product', null),
          'overlay' => Configuration::get('overlay', null),
          'overlayFrame' => Configuration::get('overlayFrame', null),
          'overlayList' => Configuration::get('overlayList', null),
          'overlaySticker' => Configuration::get('overlaySticker', null),
          'overlayButton' => Configuration::get('overlayButton', null),
          'overlaySocial' => Configuration::get('overlaySocial', null),
          'overlayDuo' => Configuration::get('overlayDuo', null),
          'textOnly' => Configuration::get('textOnly', null),
          'comments' => Configuration::get('comments', null),
          'overlayStars' => Configuration::get('overlayStars', null),
          'overlayShopak' => Configuration::get('overlayShopak', null),
          'advName' => Configuration::get('advName', null),
          'advElement' => Configuration::get('advElement', null),
          'advBadge' => Configuration::get('advBadge', null),
      );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookBackOfficeHeader() {}

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */

    public function hookDisplayFooter()
    { 
        $card_id = Configuration::get('cardId');
        $dis_overlay = Configuration::get('overlay');

        $dis_frame = Configuration::get('overlayFrame');
        $dis_list = Configuration::get('overlayList');
        $dis_sticker = Configuration::get('overlaySticker');

        $dis_button = Configuration::get('overlayButton');
        $dis_social = Configuration::get('overlaySocial');
        $dis_duo = Configuration::get('overlayDuo');

        $dis_footer = Configuration::get('footerIn');
        $dis_header = Configuration::get('headerIn');
        $dis_product = Configuration::get('product');

        $dis_adv_on = Configuration::get('advElement');
        $dis_adv = Configuration::get('advBadge');

        $dis_text = Configuration::get('textOnly');
        $dis_comments = Configuration::get('comments');
        $dis_stars = Configuration::get('overlayStars');
        $dis_shopak = Configuration::get('overlayShopak');

        if (!empty($card_id)){
          $this->context->smarty->assign(array('cardId' => $card_id));

          $this->context->smarty->assign(array('footer' => $dis_footer));
          $this->context->smarty->assign(array('header' => $dis_header));

          $this->context->smarty->assign(array('overlay' => $dis_overlay));
          $this->context->smarty->assign(array('overlayFrame' => $dis_frame));
          $this->context->smarty->assign(array('overlayList' => $dis_list));
          $this->context->smarty->assign(array('overlaySticker' => $dis_sticker));

          $this->context->smarty->assign(array('overlayButton' => $dis_button));
          $this->context->smarty->assign(array('overlaySocial' => $dis_social));
          $this->context->smarty->assign(array('overlayDuo' => $dis_duo));

          $this->context->smarty->assign(array('textOnly' => $dis_text));
          $this->context->smarty->assign(array('comments' => $dis_comments));
          $this->context->smarty->assign(array('overlayStars' => $dis_stars));
          $this->context->smarty->assign(array('overlayShopak' => $dis_shopak));

          $adv_element = Configuration::get('advElement');
          $adv_name = Configuration::get('advName');
          $adv_badge_type = Configuration::get('advBadge');

          $this->context->smarty->assign(array('advElement' => $adv_element));
          $this->context->smarty->assign(array('advName' => $adv_name));
          $this->context->smarty->assign(array('advBadgeType' => $adv_badge_type));

          return $this->display(__FILE__, 'trustami_view.tpl');
        }
    }

  public function hookDisplayTop() {}

  public function hookDisplayNav(){
      $display = Configuration::get('headerIn');
      return $this->returnedDisplay($display);
  }

  public function hookDisplayLeftColumn(){
      $display = Configuration::get('leftColumn');
      return $this->returnedDisplay($display);
  }

  public function hookDisplayRightColumn(){
      $display = Configuration::get('rightColumn');
      return $this->returnedDisplay($display);
  }

  public function hookDisplayRightColumnProduct(){
      $display = Configuration::get('product');
      return $this->returnedDisplay($display);
  }

  public function returnedDisplay($display){
      if ($display == '2') {
          return $this->display(__FILE__, 'normal.tpl');
      }
      else if ($display == '3') {
          return $this->display(__FILE__, 'badge.tpl');
      }
      else if ($display == '4') {
          return $this->display(__FILE__, 'box.tpl');
      }
         return;
    }
}
